@@ -5,12 +5,14 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 binmode(STDOUT, ":encoding(UTF-8)");
 
+use Browser::Open;
 use Getopt::Lucid 1.05 qw( :all );
 use File::HomeDir;
+use File::Temp;
 use App::Zapzi::Database;
 use App::Zapzi::Folders;
 use App::Zapzi::Articles;
@@ -100,7 +102,8 @@ sub process_args
         Switch("make-folder|mkf|md"),
         Switch("delete-folder|rmf|rd"),
         Switch("delete-article|delete|rm"),
-        Switch("show|cat"),
+        Switch("show|view"),
+        Switch("export|cat"),
         Switch("publish|pub"),
 
         Param("folder|f"),
@@ -147,7 +150,8 @@ sub process_args
     $self->delete_folder(@args) if $options->get_delete_folder;
     $self->delete_article(@args) if $options->get_delete_article;
     $self->add(@args) if $options->get_add;
-    $self->show(@args) if $options->get_show;
+    $self->show('browser', @args) if $options->get_show;
+    $self->show('stdout', @args) if $options->get_export;
     $self->publish if $options->get_publish;
 
     # Fallthrough if no valid commands given
@@ -200,7 +204,14 @@ sub validate_folder
 sub list
 {
     my $self = shift;
-    App::Zapzi::Articles::list_articles($self->folder);
+    my $summary = App::Zapzi::Articles::articles_summary($self->folder);
+    foreach (@$summary)
+    {
+        my $article = $_;
+        printf("%s %4d %s %-45s\n", $self->folder,
+               $article->{id}, $article->{created}->strftime('%d-%b-%Y'),
+               $article->{title});
+    }
     $self->run(0);
 }
 
@@ -208,7 +219,12 @@ sub list
 sub list_folders
 {
     my $self = shift;
-    App::Zapzi::Folders::list_folders();
+    my $summary = App::Zapzi::Folders::folders_summary();
+    foreach (sort keys %$summary)
+    {
+        printf("%-10s %3d\n", $_, $summary->{$_});
+    }
+
     $self->run(0);
 }
 
@@ -360,6 +376,7 @@ sub add
 sub show
 {
     my $self = shift;
+    my $output = shift;
     my @args = @_;
 
     if (! @args)
@@ -370,21 +387,40 @@ sub show
     }
 
     $self->run(0);
+    my $tempdir;
+
+    $tempdir = File::Temp->newdir("zapzi-article-XXXXX", TMPDIR => 1)
+        if $output eq 'browser';
+
     for (@args)
     {
-        my $art_rs = App::Zapzi::Articles::get_article($_);
-        if ($art_rs)
-        {
-            print "<html><head><meta charset=\"utf-8\">\n";
-            printf("<title>%s</title>\n", $art_rs->title);
-            print("</head><body>\n");
-            print $art_rs->article_text->text, "\n";
-            print("</body></html>\n\b");
-        }
-        else
+        my $article_text = App::Zapzi::Articles::export_article($_);
+        if (! $article_text)
         {
             print "Could not get article $_\n\n";
             $self->run(1);
+            next;
+        }
+
+        if ($output ne 'browser')
+        {
+            print $article_text, "\n\n";
+            next;
+        }
+
+        # Send the article to a temp file and view in a browser
+        my $tempfile = "$tempdir/$_.html";
+        open my $fh, '>:encoding(UTF-8)', $tempfile
+            or die "Can't open temporary file: $!\n";
+        print {$fh} $article_text;
+        close $fh;
+
+        my $rc = Browser::Open::open_browser($tempfile);
+        if (!defined($rc))
+        {
+            print "Could not open browser";
+            $self->run(1);
+            next;
         }
     }
 }
@@ -437,10 +473,10 @@ sub help
     Initialises new zapzi database. Will not create a new database
     if one exists already unless you set --force.
 
-  $ zapzi add [-t TRANSFORMER] FILE | URL
+  $ zapzi add [-t TRANSFORMER] FILE | URL | POD
     Adds article to database. Accepts multiple file names or URLs.
     TRANSFORMER determines how to extract the text from the article
-    and can be HTML, HTMLExtractMain or TextMarkdown
+    and can be HTML, HTMLExtractMain, POD or TextMarkdown
     If not specified, Zapzi will choose the best option based on the
     content type of the article.
 
@@ -459,8 +495,11 @@ sub help
   $ zapzi delete-article | delete | rm ID
     Removes article ID.
 
-  $ zapzi show | cat ID
-    Prints content of article to STDOUT
+  $ zapzi export | cat ID
+    Prints content of readable article to STDOUT
+
+  $ zapzi show | view ID
+    Opens a browser to view the readable text of article ID
 
   $ zapzi publish | pub [-f FOLDER] [--noarchive]
     Publishes articles in FOLDER to an eBook. Will archive articles unless
@@ -496,7 +535,7 @@ App::Zapzi - store articles and publish them to read later
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -574,7 +613,7 @@ Lists out the articles in L<folder>.
 
 =head2 list_folders
 
-List a summary of folders in the database.
+List folder names and article counts.
 
 =head2 make_folder
 
@@ -595,9 +634,10 @@ Remove an article from the database
 
 Add an article to the database for later publication.
 
-=head2 show
+=head2 show(output, articles)
 
-Outputs text of an article
+Exports article text. If C<output> is 'browser' then will start a
+browser to view the article, otherwise it will print to STDOUT.
 
 =head2 publish
 
